@@ -9,8 +9,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MULTIPLYINGLINE_H
-#define MULTIPLYINGLINE_H
+#pragma once
 
 #include "kdepim_export.h"
 
@@ -28,9 +27,7 @@ class KDEPIM_EXPORT MultiplyingLineData
 {
 public:
     using Ptr = QSharedPointer<MultiplyingLineData>;
-    virtual ~MultiplyingLineData()
-    {
-    }
+    virtual ~MultiplyingLineData() = default;
 
     /**
       Clear data, reset to defaults
@@ -54,9 +51,7 @@ class KDEPIM_EXPORT MultiplyingLine : public QWidget
     Q_OBJECT
 public:
     explicit MultiplyingLine(QWidget *parent);
-    ~MultiplyingLine() override
-    {
-    }
+    ~MultiplyingLine() override = default;
 
     /**
       This line is being activated. Focus should be set
@@ -90,7 +85,7 @@ public:
     /**
       Set the data of this line. The containing widgets should be
       populated accordingly.
-      @param data the data to populate this line wit
+      @param data the data to populate this line with
     */
     virtual void setData(const MultiplyingLineData::Ptr &data) = 0;
 
@@ -196,4 +191,3 @@ protected:
 };
 }
 
-#endif // MULTIPLYINGLINE_H
